@@ -17,6 +17,8 @@ import json
 
 from oslo_log import log as logging
 from pecan import rest
+import sqlalchemy as sa
+import tenacity
 from wsme import types as wtypes
 import wsmeext.pecan as wsme_pecan
 
@@ -26,11 +28,11 @@ from mistral.api.controllers.v2 import resources
 from mistral.api.controllers.v2 import types
 from mistral import context
 from mistral.db.v2 import api as db_api
-from mistral.engine.rpc_backend import rpc
 from mistral import exceptions as exc
+from mistral.lang import parser as spec_parser
+from mistral.rpc import clients as rpc
 from mistral.utils import filter_utils
 from mistral.utils import rest_utils
-from mistral.workbook import parser as spec_parser
 from mistral.workflow import data_flow
 from mistral.workflow import states
 
@@ -41,7 +43,8 @@ STATE_TYPES = wtypes.Enum(str, states.IDLE, states.RUNNING, states.SUCCESS,
 
 
 def _get_task_resource_with_result(task_ex):
-    task = resources.Task.from_dict(task_ex.to_dict())
+    task = resources.Task.from_db_model(task_ex)
+
     task.result = json.dumps(data_flow.get_task_execution_result(task_ex))
 
     return task
@@ -129,6 +132,19 @@ class TaskExecutionsController(rest.RestController):
         )
 
 
+# Use retries to prevent possible failures.
+@tenacity.retry(
+    retry=tenacity.retry_if_exception_type(sa.exc.OperationalError),
+    stop=tenacity.stop_after_attempt(10),
+    wait=tenacity.wait_incrementing(increment=100)  # 0.1 seconds
+)
+def _get_task_execution(id):
+    with db_api.transaction():
+        task_ex = db_api.get_task_execution(id)
+
+        return _get_task_resource_with_result(task_ex)
+
+
 class TasksController(rest.RestController):
     action_executions = action_execution.TasksActionExecutionController()
     workflow_executions = TaskExecutionsController()
@@ -136,14 +152,14 @@ class TasksController(rest.RestController):
     @rest_utils.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(resources.Task, wtypes.text)
     def get(self, id):
-        """Return the specified task."""
+        """Return the specified task.
+
+        :param id: UUID of task to retrieve
+        """
         acl.enforce('tasks:get', context.ctx())
-        LOG.info("Fetch task [id=%s]" % id)
+        LOG.info("Fetch task [id=%s]", id)
 
-        with db_api.transaction():
-            task_ex = db_api.get_task_execution(id)
-
-            return _get_task_resource_with_result(task_ex)
+        return _get_task_execution(id)
 
     @rest_utils.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(resources.Tasks, types.uuid, int, types.uniquelist,
@@ -244,7 +260,7 @@ class TasksController(rest.RestController):
         """
         acl.enforce('tasks:update', context.ctx())
 
-        LOG.info("Update task execution [id=%s, task=%s]" % (id, task))
+        LOG.info("Update task execution [id=%s, task=%s]", id, task)
 
         with db_api.transaction():
             task_ex = db_api.get_task_execution(id)
