@@ -44,7 +44,7 @@ class Task(object):
     """
 
     def __init__(self, wf_ex, wf_spec, task_spec, ctx, task_ex=None,
-                 unique_key=None, waiting=False):
+                 unique_key=None, waiting=False, triggered_by=None):
         self.wf_ex = wf_ex
         self.task_spec = task_spec
         self.ctx = ctx
@@ -52,6 +52,7 @@ class Task(object):
         self.wf_spec = wf_spec
         self.unique_key = unique_key
         self.waiting = waiting
+        self.triggered_by = triggered_by
         self.reset_flag = False
         self.created = False
         self.state_changed = False
@@ -76,6 +77,14 @@ class Task(object):
         """
         raise NotImplementedError
 
+    @abc.abstractmethod
+    def on_action_update(self, action_ex):
+        """Handle action update.
+
+        :param action_ex: Action execution.
+        """
+        raise NotImplementedError
+
     @abc.abstractmethod
     def run(self):
         """Runs task."""
@@ -116,29 +125,43 @@ class Task(object):
         :param state: New task state.
         :param state_info: New state information (i.e. error message).
         :param processed: New "processed" flag value.
+        :return True if the state was changed as a result of this call,
+            False otherwise.
         """
 
         assert self.task_ex
 
-        if (self.task_ex.state != state or
-                self.task_ex.state_info != state_info):
+        cur_state = self.task_ex.state
+
+        if cur_state != state or self.task_ex.state_info != state_info:
+            task_ex = db_api.update_task_execution_state(
+                id=self.task_ex.id,
+                cur_state=cur_state,
+                state=state
+            )
+
+            if task_ex is None:
+                # Do nothing because the update query did not change the DB.
+                return False
+
+            self.task_ex = task_ex
+            self.task_ex.state_info = state_info
+            self.state_changed = True
+
+            if processed is not None:
+                self.task_ex.processed = processed
+
             wf_trace.info(
                 self.task_ex.workflow_execution,
                 "Task '%s' (%s) [%s -> %s, msg=%s]" %
                 (self.task_ex.name,
                  self.task_ex.id,
-                 self.task_ex.state,
+                 cur_state,
                  state,
                  state_info)
             )
 
-            self.state_changed = True
-
-        self.task_ex.state = state
-        self.task_ex.state_info = state_info
-
-        if processed is not None:
-            self.task_ex.processed = processed
+        return True
 
     @profiler.trace('task-complete')
     def complete(self, state, state_info=None):
@@ -155,10 +178,15 @@ class Task(object):
         assert self.task_ex
 
         # Ignore if task already completed.
-        if states.is_completed(self.task_ex.state):
+        if self.is_completed():
             return
 
-        self.set_state(state, state_info)
+        # If we were unable to change the task state it means that it was
+        # already changed by a concurrent process. In this case we need to
+        # skip all regular completion logic like scheduling new tasks,
+        # running engine commands and publishing.
+        if not self.set_state(state, state_info):
+            return
 
         data_flow.publish_variables(self.task_ex, self.task_spec)
 
@@ -190,6 +218,35 @@ class Task(object):
 
         dispatcher.dispatch_workflow_commands(self.wf_ex, cmds)
 
+    @profiler.trace('task-update')
+    def update(self, state, state_info=None):
+        """Update task and set specified state.
+
+        Method sets specified task state.
+
+        :param state: New task state.
+        :param state_info: New state information (i.e. error message).
+        """
+
+        assert self.task_ex
+
+        # Ignore if task already completed.
+        if states.is_completed(self.task_ex.state):
+            return
+
+        # Update only if state transition is valid.
+        if not states.is_valid_transition(self.task_ex.state, state):
+            return
+
+        # We can't set the task state to RUNNING if some other
+        # child executions are paused.
+        child_states = [a_ex.state for a_ex in self.task_ex.executions]
+
+        if state == states.RUNNING and states.PAUSED in child_states:
+            return
+
+        self.set_state(state, state_info)
+
     def _before_task_start(self):
         policies_spec = self.task_spec.get_policies()
 
@@ -215,6 +272,7 @@ class Task(object):
             'name': task_name,
             'workflow_execution_id': self.wf_ex.id,
             'workflow_name': self.wf_ex.workflow_name,
+            'workflow_namespace': self.wf_ex.workflow_namespace,
             'workflow_id': self.wf_ex.workflow_id,
             'state': state,
             'state_info': state_info,
@@ -227,6 +285,9 @@ class Task(object):
             'type': task_type
         }
 
+        if self.triggered_by:
+            values['runtime_context']['triggered_by'] = self.triggered_by
+
         self.task_ex = db_api.create_task_execution(values)
 
         # Add to collection explicitly so that it's in a proper
@@ -263,6 +324,10 @@ class RegularTask(Task):
 
         self.complete(state, state_info)
 
+    @profiler.trace('regular-task-on-action-update', hide_args=True)
+    def on_action_update(self, action_ex):
+        self.update(action_ex.state)
+
     @profiler.trace('task-run')
     def run(self):
         if not self.task_ex:
@@ -280,8 +345,10 @@ class RegularTask(Task):
         self._create_task_execution()
 
         LOG.debug(
-            'Starting task [workflow=%s, task_spec=%s, init_state=%s]' %
-            (self.wf_ex.name, self.task_spec, self.task_ex.state)
+            'Starting task [workflow=%s, task=%s, init_state=%s]',
+            self.wf_ex.name,
+            self.task_spec.get_name(),
+            self.task_ex.state
         )
 
         self._before_task_start()
@@ -307,17 +374,29 @@ class RegularTask(Task):
         self.set_state(states.RUNNING, None, processed=False)
 
         self._update_inbound_context()
+        self._update_triggered_by()
         self._reset_actions()
         self._schedule_actions()
 
     def _update_inbound_context(self):
-        assert self.task_ex
+        task_ex = self.task_ex
+        assert task_ex
 
         wf_ctrl = wf_base.get_controller(self.wf_ex, self.wf_spec)
 
         self.ctx = wf_ctrl.get_task_inbound_context(self.task_spec)
+        data_flow.add_current_task_to_context(self.ctx, task_ex.id,
+                                              task_ex.name)
 
-        utils.update_dict(self.task_ex.in_context, self.ctx)
+        utils.update_dict(task_ex.in_context, self.ctx)
+
+    def _update_triggered_by(self):
+        assert self.task_ex
+
+        if not self.triggered_by:
+            return
+
+        self.task_ex.runtime_context['triggered_by'] = self.triggered_by
 
     def _reset_actions(self):
         """Resets task state.
@@ -368,18 +447,14 @@ class RegularTask(Task):
 
     @profiler.trace('regular-task-get-action-input', hide_args=True)
     def _get_action_input(self, ctx=None):
-        ctx = ctx or self.ctx
+        input_dict = self._evaluate_expression(self.task_spec.get_input(), ctx)
 
-        ctx_view = data_flow.ContextView(
-            ctx,
-            self.wf_ex.context,
-            self.wf_ex.input
-        )
-
-        input_dict = expr.evaluate_recursively(
-            self.task_spec.get_input(),
-            ctx_view
-        )
+        if not isinstance(input_dict, dict):
+            raise exc.InputException(
+                "Wrong dynamic input for task: %s. Dict type is expected. "
+                "Actual type: %s. Actual value: %s" %
+                (self.task_spec.get_name(), type(input_dict), str(input_dict))
+            )
 
         return utils.merge_dicts(
             input_dict,
@@ -387,12 +462,28 @@ class RegularTask(Task):
             overwrite=False
         )
 
+    def _evaluate_expression(self, expression, ctx=None):
+        ctx = ctx or self.ctx
+        ctx_view = data_flow.ContextView(
+            ctx,
+            self.wf_ex.context,
+            self.wf_ex.input
+        )
+        input_dict = expr.evaluate_recursively(
+            expression,
+            ctx_view
+        )
+        return input_dict
+
     def _build_action(self):
         action_name = self.task_spec.get_action_name()
         wf_name = self.task_spec.get_workflow_name()
 
         if wf_name:
-            return actions.WorkflowAction(wf_name, task_ex=self.task_ex)
+            return actions.WorkflowAction(
+                wf_name=self._evaluate_expression(wf_name),
+                task_ex=self.task_ex
+            )
 
         if not action_name:
             action_name = 'std.noop'
@@ -404,7 +495,9 @@ class RegularTask(Task):
         )
 
         if action_def.spec:
-            return actions.AdHocAction(action_def, task_ex=self.task_ex)
+            return actions.AdHocAction(action_def, task_ex=self.task_ex,
+                                       task_ctx=self.ctx,
+                                       wf_ctx=self.wf_ex.context)
 
         return actions.PythonAction(action_def, task_ex=self.task_ex)
 
@@ -430,52 +523,41 @@ class WithItemsTask(RegularTask):
     def on_action_complete(self, action_ex):
         assert self.task_ex
 
-        if (not self._get_concurrency() and
-                not self.task_spec.get_policies().get_retry()):
-            self._on_action_complete(action_ex)
-        else:
-            # If we need to control 'concurrency' we need to do atomic
-            # reads/writes to task runtime context. Locking prevents us
-            # from modifying runtime context simultaneously by multiple
-            # transactions.
-            with db_api.named_lock('with-items-%s' % self.task_ex.id):
-                # NOTE: We need to refresh task execution object right
-                # after the lock is acquired to make sure that we're
-                # working with a fresh state of its runtime context.
-                # Otherwise, SQLAlchemy session can contain a stale
-                # cached version of it so that we don't modify actual
-                # values (i.e. capacity).
-                db_api.refresh(self.task_ex)
+        with db_api.named_lock('with-items-%s' % self.task_ex.id):
+            # NOTE: We need to refresh task execution object right
+            # after the lock is acquired to make sure that we're
+            # working with a fresh state of its runtime context.
+            # Otherwise, SQLAlchemy session can contain a stale
+            # cached version of it so that we don't modify actual
+            # values (i.e. capacity).
+            db_api.refresh(self.task_ex)
 
-                self._on_action_complete(action_ex)
+            if self.is_completed():
+                return
 
-    def _on_action_complete(self, action_ex):
-        if self.is_completed():
-            return
+            self._increase_capacity()
 
-        self._increase_capacity()
+            if self.is_with_items_completed():
+                state = self._get_final_state()
 
-        if self.is_with_items_completed():
-            state = self._get_final_state()
+                # TODO(rakhmerov): Here we can define more informative messages
+                # in cases when action is successful and when it's not.
+                # For example, in state_info we can specify the cause action.
+                # The use of action_ex.output.get('result') for state_info is
+                # not accurate because there could be action executions that
+                # had failed or was cancelled prior to this action execution.
+                state_info = {
+                    states.SUCCESS: None,
+                    states.ERROR: 'One or more actions had failed.',
+                    states.CANCELLED: 'One or more actions was cancelled.'
+                }
 
-            # TODO(rakhmerov): Here we can define more informative messages
-            # in cases when action is successful and when it's not.
-            # For example, in state_info we can specify the cause action.
-            # The use of action_ex.output.get('result') for state_info is not
-            # accurate because there could be action executions that had
-            # failed or was cancelled prior to this action execution.
-            state_info = {
-                states.SUCCESS: None,
-                states.ERROR: 'One or more actions had failed.',
-                states.CANCELLED: 'One or more actions was cancelled.'
-            }
+                self.complete(state, state_info[state])
 
-            self.complete(state, state_info[state])
+                return
 
-            return
-
-        if self._has_more_iterations() and self._get_concurrency():
-            self._schedule_actions()
+            if self._has_more_iterations() and self._get_concurrency():
+                self._schedule_actions()
 
     def _schedule_actions(self):
         with_items_values = self._get_with_items_values()
