@@ -13,7 +13,9 @@
 #    limitations under the License.
 
 import copy
+
 import mock
+import sqlalchemy as sa
 
 from mistral.db.v2 import api as db_api
 from mistral.db.v2.sqlalchemy import models
@@ -130,6 +132,19 @@ class TestActionsController(base.APITest):
         self.assertEqual(200, resp.status_int)
         self.assertDictEqual(ACTION, resp.json)
 
+    @mock.patch.object(db_api, 'get_action_definition')
+    def test_get_operational_error(self, mocked_get):
+        mocked_get.side_effect = [
+            # Emulating DB OperationalError
+            sa.exc.OperationalError('Mock', 'mock', 'mock'),
+            ACTION_DB  # Successful run
+        ]
+
+        resp = self.app.get('/v2/actions/my_action')
+
+        self.assertEqual(200, resp.status_int)
+        self.assertDictEqual(ACTION, resp.json)
+
     @mock.patch.object(
         db_api, "get_action_definition", MOCK_NOT_FOUND)
     def test_get_not_found(self):
@@ -312,6 +327,21 @@ class TestActionsController(base.APITest):
         self.assertEqual(1, len(resp.json['actions']))
         self.assertDictEqual(ACTION, resp.json['actions'][0])
 
+    @mock.patch.object(db_api, 'get_action_definitions')
+    def test_get_all_operational_error(self, mocked_get_all):
+        mocked_get_all.side_effect = [
+            # Emulating DB OperationalError
+            sa.exc.OperationalError('Mock', 'mock', 'mock'),
+            [ACTION_DB]  # Successful run
+        ]
+
+        resp = self.app.get('/v2/actions')
+
+        self.assertEqual(200, resp.status_int)
+
+        self.assertEqual(1, len(resp.json['actions']))
+        self.assertDictEqual(ACTION, resp.json['actions'][0])
+
     @mock.patch.object(
         db_api, "get_action_definitions", MOCK_EMPTY)
     def test_get_all_empty(self):
