@@ -14,7 +14,9 @@
 
 import copy
 import json
+
 import mock
+import sqlalchemy as sa
 
 from mistral.db.v2 import api as db_api
 from mistral.db.v2.sqlalchemy import models
@@ -75,6 +77,19 @@ class TestCronTriggerController(base.APITest):
         self.assertEqual(200, resp.status_int)
         self.assertDictEqual(TRIGGER, resp.json)
 
+    @mock.patch.object(db_api, 'get_cron_trigger')
+    def test_get_operational_error(self, mocked_get):
+        mocked_get.side_effect = [
+            # Emulating DB OperationalError
+            sa.exc.OperationalError('Mock', 'mock', 'mock'),
+            TRIGGER_DB  # Successful run
+        ]
+
+        resp = self.app.get('/v2/cron_triggers/my_cron_trigger')
+
+        self.assertEqual(200, resp.status_int)
+        self.assertDictEqual(TRIGGER, resp.json)
+
     @mock.patch.object(db_api, "get_cron_trigger", MOCK_NOT_FOUND)
     def test_get_not_found(self):
         resp = self.app.get(
@@ -151,6 +166,21 @@ class TestCronTriggerController(base.APITest):
         self.assertEqual(1, len(resp.json['cron_triggers']))
         self.assertDictEqual(TRIGGER, resp.json['cron_triggers'][0])
 
+    @mock.patch.object(db_api, 'get_cron_triggers')
+    def test_get_all_operational_error(self, mocked_get_all):
+        mocked_get_all.side_effect = [
+            # Emulating DB OperationalError
+            sa.exc.OperationalError('Mock', 'mock', 'mock'),
+            [TRIGGER_DB]  # Successful run
+        ]
+
+        resp = self.app.get('/v2/cron_triggers')
+
+        self.assertEqual(200, resp.status_int)
+
+        self.assertEqual(1, len(resp.json['cron_triggers']))
+        self.assertDictEqual(TRIGGER, resp.json['cron_triggers'][0])
+
     @mock.patch.object(db_api, 'get_cron_triggers')
     @mock.patch('mistral.context.MistralContext.from_environ')
     def test_get_all_projects_admin(self, mock_context, mock_get_triggers):
