@@ -14,7 +14,9 @@
 
 import copy
 import json
+
 import mock
+import sqlalchemy as sa
 
 from mistral.db.v2 import api as db_api
 from mistral.db.v2.sqlalchemy import models
@@ -74,6 +76,21 @@ class TestEventTriggerController(base.APITest):
         self.assertEqual(200, resp.status_int)
         self.assertDictEqual(TRIGGER, resp.json)
 
+    @mock.patch.object(db_api, 'get_event_trigger')
+    def test_get_operational_error(self, mocked_get):
+        mocked_get.side_effect = [
+            # Emulating DB OperationalError
+            sa.exc.OperationalError('Mock', 'mock', 'mock'),
+            TRIGGER_DB  # Successful run
+        ]
+
+        resp = self.app.get(
+            '/v2/event_triggers/09cc56a9-d15e-4494-a6e2-c4ec8bdaacae'
+        )
+
+        self.assertEqual(200, resp.status_int)
+        self.assertDictEqual(TRIGGER, resp.json)
+
     @mock.patch.object(db_api, "get_event_trigger", MOCK_NOT_FOUND)
     def test_get_not_found(self):
         resp = self.app.get(
@@ -230,6 +247,21 @@ class TestEventTriggerController(base.APITest):
         self.assertEqual(1, len(resp.json['event_triggers']))
         self.assertDictEqual(TRIGGER, resp.json['event_triggers'][0])
 
+    @mock.patch.object(db_api, 'get_event_triggers')
+    def test_get_all_operational_error(self, mocked_get_all):
+        mocked_get_all.side_effect = [
+            # Emulating DB OperationalError
+            sa.exc.OperationalError('Mock', 'mock', 'mock'),
+            [TRIGGER_DB]  # Successful run
+        ]
+
+        resp = self.app.get('/v2/event_triggers')
+
+        self.assertEqual(200, resp.status_int)
+
+        self.assertEqual(1, len(resp.json['event_triggers']))
+        self.assertDictEqual(TRIGGER, resp.json['event_triggers'][0])
+
     @mock.patch('mistral.db.v2.api.get_event_triggers')
     @mock.patch('mistral.context.MistralContext.from_environ')
     def test_get_all_projects_admin(self, mock_context, mock_get_wf_defs):
