@@ -17,11 +17,11 @@ from oslo_config import cfg
 import tooz.coordination
 from webtest import app as webtest_app
 
-from mistral import coordination
+from mistral.service import coordination
 from mistral.tests.unit.api import base
 
 
-class TestServicesController(base.FunctionalTest):
+class TestServicesController(base.APITest):
     def test_get_all(self):
         cfg.CONF.set_default('backend_url', 'zake://', 'coordination')
 
@@ -52,9 +52,9 @@ class TestServicesController(base.FunctionalTest):
             '/v2/services',
         )
 
-        self.assertIn('Service API is not supported', context.message)
+        self.assertIn('Service API is not supported', context.args[0])
 
-    @mock.patch('mistral.coordination.ServiceCoordinator.get_members',
+    @mock.patch('mistral.service.coordination.ServiceCoordinator.get_members',
                 side_effect=tooz.coordination.ToozError('error message'))
     def test_get_all_with_get_members_error(self, mock_get_members):
         cfg.CONF.set_default('backend_url', 'zake://', 'coordination')
@@ -70,5 +70,5 @@ class TestServicesController(base.FunctionalTest):
 
         self.assertIn(
             'Failed to get service members from coordination backend',
-            context.message
+            context.args[0]
         )
