@@ -17,6 +17,7 @@ import copy
 import datetime
 
 import mock
+import sqlalchemy as sa
 
 from mistral.db.v2 import api as db_api
 from mistral.db.v2.sqlalchemy import models
@@ -194,6 +195,19 @@ class TestWorkflowsController(base.APITest):
         self.assertEqual(200, resp.status_int)
         self.assertDictEqual(WF, resp.json)
 
+    @mock.patch.object(db_api, 'get_workflow_definition')
+    def test_get_operational_error(self, mocked_get):
+        mocked_get.side_effect = [
+            # Emulating DB OperationalError
+            sa.exc.OperationalError('Mock', 'mock', 'mock'),
+            WF_DB  # Successful run
+        ]
+
+        resp = self.app.get('/v2/workflows/123')
+
+        self.assertEqual(200, resp.status_int)
+        self.assertDictEqual(WF, resp.json)
+
     @mock.patch.object(db_api, "get_workflow_definition", MOCK_WF_WITH_INPUT)
     def test_get_with_input(self):
         resp = self.app.get('/v2/workflows/123')
@@ -433,9 +447,21 @@ class TestWorkflowsController(base.APITest):
         self.assertEqual(200, resp.status_int)
 
         self.assertEqual(1, len(resp.json['workflows']))
+        self.assertDictEqual(WF, resp.json['workflows'][0])
 
-        print(resp.json['workflows'][0])
+    @mock.patch.object(db_api, 'get_workflow_definitions')
+    def test_get_all_operational_error(self, mocked_get_all):
+        mocked_get_all.side_effect = [
+            # Emulating DB OperationalError
+            sa.exc.OperationalError('Mock', 'mock', 'mock'),
+            [WF_DB]  # Successful run
+        ]
 
+        resp = self.app.get('/v2/workflows')
+
+        self.assertEqual(200, resp.status_int)
+
+        self.assertEqual(1, len(resp.json['workflows']))
         self.assertDictEqual(WF, resp.json['workflows'][0])
 
     @mock.patch.object(db_api, "get_workflow_definitions", MOCK_EMPTY)
