@@ -22,7 +22,7 @@ from mistral.services import workbooks as wb_service
 from mistral.services import workflows as wf_service
 from mistral.tests.unit.engine import base
 from mistral.workflow import states
-from mistral.workflow import utils as wf_utils
+from mistral_lib import actions as ml_actions
 
 
 class TaskCancelTest(base.EngineTestCase):
@@ -32,7 +32,6 @@ class TaskCancelTest(base.EngineTestCase):
         version: '2.0'
 
         wf:
-          type: direct
           tasks:
             task1:
               action: std.async_noop
@@ -53,7 +52,7 @@ class TaskCancelTest(base.EngineTestCase):
 
         wf_service.create_workflows(workflow)
 
-        wf_ex = self.engine.start_workflow('wf', {})
+        wf_ex = self.engine.start_workflow('wf', '', {})
 
         self.await_workflow_state(wf_ex.id, states.RUNNING)
 
@@ -76,7 +75,7 @@ class TaskCancelTest(base.EngineTestCase):
 
         self.engine.on_action_complete(
             task_1_action_exs[0].id,
-            wf_utils.Result(cancel=True)
+            ml_actions.Result(cancel=True)
         )
 
         self.await_workflow_cancelled(wf_ex.id)
@@ -119,13 +118,11 @@ class TaskCancelTest(base.EngineTestCase):
 
         workflows:
             wf:
-              type: direct
               tasks:
                 taskx:
                   workflow: subwf
 
             subwf:
-              type: direct
               tasks:
                 task1:
                   action: std.async_noop
@@ -146,7 +143,7 @@ class TaskCancelTest(base.EngineTestCase):
 
         wb_service.create_workbook_v2(workbook)
 
-        wf_ex = self.engine.start_workflow('wb.wf', {})
+        wf_ex = self.engine.start_workflow('wb.wf', '', {})
 
         self.await_workflow_state(wf_ex.id, states.RUNNING)
 
@@ -174,7 +171,7 @@ class TaskCancelTest(base.EngineTestCase):
 
         self.engine.on_action_complete(
             task_1_action_exs[0].id,
-            wf_utils.Result(cancel=True)
+            ml_actions.Result(cancel=True)
         )
 
         self.await_workflow_cancelled(subwf_ex.id)
@@ -207,7 +204,6 @@ class TaskCancelTest(base.EngineTestCase):
         version: '2.0'
 
         wf:
-          type: direct
           tasks:
             task1:
               action: std.async_noop
@@ -223,7 +219,7 @@ class TaskCancelTest(base.EngineTestCase):
 
         wf_service.create_workflows(workflow)
 
-        wf_ex = self.engine.start_workflow('wf', {})
+        wf_ex = self.engine.start_workflow('wf', '', {})
 
         self.await_workflow_state(wf_ex.id, states.RUNNING)
 
@@ -246,7 +242,7 @@ class TaskCancelTest(base.EngineTestCase):
 
         self.engine.on_action_complete(
             task_1_action_exs[0].id,
-            wf_utils.Result(cancel=True)
+            ml_actions.Result(cancel=True)
         )
 
         self.await_workflow_cancelled(wf_ex.id)
@@ -294,10 +290,11 @@ class TaskCancelTest(base.EngineTestCase):
     def test_cancel_with_items_concurrency(self):
         wb_def = """
             version: '2.0'
+
             name: wb1
+
             workflows:
               wf1:
-                type: direct
                 tasks:
                   t1:
                     with-items: i in <% list(range(0, 4)) %>
@@ -311,7 +308,7 @@ class TaskCancelTest(base.EngineTestCase):
 
         wb_service.create_workbook_v2(wb_def)
 
-        wf1_ex = self.engine.start_workflow('wb1.wf1', {})
+        wf1_ex = self.engine.start_workflow('wb1.wf1', '', {})
 
         self.await_workflow_state(wf1_ex.id, states.RUNNING)
 
@@ -336,7 +333,7 @@ class TaskCancelTest(base.EngineTestCase):
         for wf1_t1_action_ex in wf1_t1_action_exs:
             self.engine.on_action_complete(
                 wf1_t1_action_ex.id,
-                wf_utils.Result(cancel=True)
+                ml_actions.Result(cancel=True)
             )
 
         self.await_task_cancelled(wf1_t1_ex.id)
