@@ -13,27 +13,33 @@
 #    limitations under the License.
 
 from mistral.db.v2 import api as db_api
-from mistral.tests import base
+from mistral.tests.unit import base
 
 
 class ActionManagerTest(base.DbTestCase):
     def test_action_input(self):
-        std_http = db_api.get_action("std.http")
-        std_email = db_api.get_action("std.email")
+        std_http = db_api.get_action_definition("std.http")
+        std_email = db_api.get_action_definition("std.email")
 
         http_action_input = (
-            "url, method=GET, params=None, body=None, "
-            "headers=None, cookies=None, auth=None, "
-            "timeout=None, allow_redirects=None, "
-            "proxies=None"
+            'url, method="GET", params=null, body=null, '
+            'headers=null, cookies=null, auth=null, '
+            'timeout=null, allow_redirects=null, '
+            'proxies=null, verify=null'
         )
 
         self.assertEqual(http_action_input, std_http.input)
-        self.assertEqual("params, settings", std_email.input)
+
+        std_email_input = (
+            "from_addr, to_addrs, smtp_server, "
+            "smtp_password=null, subject=null, body=null"
+        )
+
+        self.assertEqual(std_email_input, std_email.input)
 
     def test_action_description(self):
-        std_http = db_api.get_action("std.http")
-        std_echo = db_api.get_action("std.echo")
+        std_http = db_api.get_action_definition("std.http")
+        std_echo = db_api.get_action_definition("std.echo")
 
         self.assertIn("Constructs an HTTP action", std_http.description)
         self.assertIn("param body: (optional) Dictionary, bytes",
