@@ -13,7 +13,7 @@
 # under the License.
 
 from oslo_concurrency.fixture import lockutils
-from tempest import test
+from tempest.lib import decorators
 
 from mistral_tempest_tests.tests import base
 
@@ -28,6 +28,7 @@ class TasksTestsV2(base.TestCase):
         _, body = self.client.create_workflow('wf_v2.yaml')
         self.direct_wf_name = body['workflows'][0]['name']
         _, execution = self.client.create_execution(self.direct_wf_name)
+        self.execution_id = execution['id']
 
     def tearDown(self):
         for wf in self.client.workflows:
@@ -40,14 +41,16 @@ class TasksTestsV2(base.TestCase):
 
         super(TasksTestsV2, self).tearDown()
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
+    @decorators.idempotent_id('81159dce-3802-44ee-a8d4-5ddca106fd91')
     def test_get_tasks_list(self):
         resp, body = self.client.get_list_obj('tasks')
 
         self.assertEqual(200, resp.status)
         self.assertNotEmpty(body['tasks'])
 
-    @test.attr(type='sanity')
+    @decorators.attr(type='sanity')
+    @decorators.idempotent_id('f62664de-bd2b-4153-8d0f-5a76d78abbad')
     def test_get_task(self):
         resp, body = self.client.get_list_obj('tasks')
 
@@ -56,6 +59,17 @@ class TasksTestsV2(base.TestCase):
             self.direct_wf_name, body['tasks'][-1]['workflow_name']
         )
 
+    @decorators.attr(type='sanity')
+    @decorators.idempotent_id('3230d694-40fd-4094-ad12-024f40a21b94')
+    def test_get_tasks_of_execution(self):
+        resp, body = self.client.get_list_obj(
+            'tasks?workflow_execution_id=%s' % self.execution_id)
+
+        self.assertEqual(200, resp.status)
+        self.assertEqual(
+            self.direct_wf_name, body['tasks'][-1]['workflow_name']
+        )
+
 
 class TaskTypesTestsV2(base.TestCase):
 
@@ -70,14 +84,15 @@ class TaskTypesTestsV2(base.TestCase):
         self.nested_wf_name = 'wb_with_nested_wf.wrapping_wf'
         _, execution = self.client.create_execution(self.nested_wf_name)
 
-    @test.attr(type='sanity')
+    @decorators.attr(type='sanity')
+    @decorators.idempotent_id('1ac726eb-b945-4b82-8755-a2fb2dc009bc')
     def test_task_type(self):
         resp, body = self.client.get_list_obj('tasks')
 
         self.assertEqual(200, resp.status)
 
         bt = body['tasks']
-        ll = [[v for k, v in d.iteritems() if 'type' in k] for d in bt]
+        ll = [[v for k, v in d.items() if 'type' in k] for d in bt]
         types_list = [item for sublist in ll for item in sublist]
 
         self.assertIn(
