@@ -14,8 +14,8 @@
 import json
 
 from oslo_concurrency.fixture import lockutils
+from tempest.lib import decorators
 from tempest.lib import exceptions
-from tempest import test
 
 from mistral import utils
 from mistral_tempest_tests.tests import base
@@ -32,7 +32,8 @@ class WorkflowTestsV2(base.TestCase):
 
         super(WorkflowTestsV2, self).tearDown()
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
+    @decorators.idempotent_id('e9cd6817-e8d1-4604-ba76-b0e17219f4c5')
     def test_get_list_workflows(self):
         resp, body = self.client.get_list_obj('workflows')
         self.assertEqual(200, resp.status)
@@ -43,7 +44,8 @@ class WorkflowTestsV2(base.TestCase):
 
         self.assertNotIn('next', body)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
+    @decorators.idempotent_id('be8a4a44-eeb3-48e3-b11d-b83ba14dbf2c')
     def test_get_list_workflows_by_admin(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
 
@@ -59,7 +61,8 @@ class WorkflowTestsV2(base.TestCase):
 
         self.assertIn(name, names)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
+    @decorators.idempotent_id('c9e2ebbc-02aa-4c33-b244-e471c8266aa7')
     def test_get_list_workflows_with_project_by_admin(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
 
@@ -79,7 +82,8 @@ class WorkflowTestsV2(base.TestCase):
 
         self.assertIn(name, names)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
+    @decorators.idempotent_id('b8dc1b02-8509-45e2-9df7-4630cdcfa1ab')
     def test_get_list_other_project_private_workflows(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
 
@@ -99,7 +103,8 @@ class WorkflowTestsV2(base.TestCase):
 
         self.assertNotIn(name, names)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
+    @decorators.idempotent_id('2063143b-ced8-4037-9383-e2504be581e6')
     def test_get_list_workflows_with_fields(self):
         resp, body = self.client.get_list_obj('workflows?fields=name')
 
@@ -108,7 +113,8 @@ class WorkflowTestsV2(base.TestCase):
         for wf in body['workflows']:
             self.assertListEqual(sorted(['id', 'name']), sorted(list(wf)))
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
+    @decorators.idempotent_id('81f28735-e74e-4dc1-8b94-b548f8a80556')
     def test_get_list_workflows_with_pagination(self):
         resp, body = self.client.get_list_obj(
             'workflows?limit=1&sort_keys=name&sort_dirs=desc'
@@ -147,7 +153,8 @@ class WorkflowTestsV2(base.TestCase):
 
         self.assertGreater(name_1, name_2)
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('cdb5586f-a72f-4371-88d1-1472675915c3')
     def test_get_list_workflows_nonexist_sort_dirs(self):
         context = self.assertRaises(
             exceptions.BadRequest,
@@ -160,7 +167,8 @@ class WorkflowTestsV2(base.TestCase):
             context.resp_body.get('faultstring')
         )
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('ac41a0ea-2be6-4307-9003-6b8dd52b0bf9')
     def test_get_list_workflows_invalid_limit(self):
         context = self.assertRaises(
             exceptions.BadRequest,
@@ -173,7 +181,8 @@ class WorkflowTestsV2(base.TestCase):
             context.resp_body.get('faultstring')
         )
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('55759713-a8d7-44c2-aff1-2383f51136bd')
     def test_get_list_workflows_duplicate_sort_keys(self):
         context = self.assertRaises(
             exceptions.BadRequest,
@@ -186,7 +195,8 @@ class WorkflowTestsV2(base.TestCase):
             context.resp_body.get('faultstring')
         )
 
-    @test.attr(type='sanity')
+    @decorators.attr(type='sanity')
+    @decorators.idempotent_id('e26b30b9-6699-4020-93a0-e25c2daca59a')
     def test_create_and_delete_workflow(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
         resp, body = self.client.create_workflow('wf_v2.yaml')
@@ -208,7 +218,8 @@ class WorkflowTestsV2(base.TestCase):
         names = [wf['name'] for wf in body['workflows']]
         self.assertNotIn(name, names)
 
-    @test.attr(type='sanity')
+    @decorators.attr(type='sanity')
+    @decorators.idempotent_id('f5a4a771-79b2-4f28-bfac-940aa83990a4')
     def test_get_workflow(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
         _, body = self.client.create_workflow('wf_v2.yaml')
@@ -219,18 +230,72 @@ class WorkflowTestsV2(base.TestCase):
         self.assertEqual(200, resp.status)
         self.assertEqual(name, body['name'])
 
-    @test.attr(type='sanity')
+    @decorators.attr(type='sanity')
+    @decorators.idempotent_id('f516aad0-9a50-4ace-a217-fa1931fd9335')
     def test_update_workflow(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
-        _, body = self.client.create_workflow('wf_v2.yaml')
+        _, body = self.client.create_workflow('single_wf.yaml')
         name = body['workflows'][0]['name']
 
-        resp, body = self.client.update_request('workflows', 'wf_v2.yaml')
+        resp, body = self.client.update_request('workflows', 'single_wf.yaml')
 
         self.assertEqual(200, resp.status)
         self.assertEqual(name, body['workflows'][0]['name'])
 
-    @test.attr(type='sanity')
+    @decorators.attr(type='sanity')
+    @decorators.idempotent_id('42f5d135-a2b8-4a31-8135-c5ce8c5f1ed5')
+    def test_workflow_within_namespace(self):
+        self.useFixture(lockutils.LockFixture('mistral-workflow'))
+
+        namespace = 'abc'
+        resp, body = self.client.create_workflow(
+            'single_wf.yaml',
+            namespace=namespace
+        )
+        name = body['workflows'][0]['name']
+        id = body['workflows'][0]['id']
+
+        self.assertEqual(201, resp.status)
+        self.assertEqual(name, body['workflows'][0]['name'])
+
+        resp, body = self.client.get_workflow(
+            id
+        )
+
+        self.assertEqual(namespace, body['namespace'])
+
+        resp, body = self.client.update_workflow('single_wf.yaml', namespace)
+
+        self.assertEqual(200, resp.status)
+        self.assertEqual(name, body['workflows'][0]['name'])
+        self.assertEqual(namespace, body['workflows'][0]['namespace'])
+
+        namespace = 'abc2'
+        resp, body = self.client.create_workflow(
+            'single_wf.yaml',
+            namespace=namespace
+        )
+        name = body['workflows'][0]['name']
+        id = body['workflows'][0]['id']
+
+        self.assertEqual(201, resp.status)
+        self.assertEqual(name, body['workflows'][0]['name'])
+
+        resp, body = self.client.get_workflow(id)
+
+        self.assertEqual(namespace, body['namespace'])
+
+        self.assertRaises(exceptions.NotFound, self.client.get_workflow, name)
+
+        self.client.create_workflow(
+            'single_wf.yaml'
+        )
+
+        resp, body = self.client.get_workflow(id)
+        self.assertEqual(200, resp.status)
+
+    @decorators.attr(type='sanity')
+    @decorators.idempotent_id('02bc1fc3-c31a-4e37-bb3d-eda46818505c')
     def test_get_workflow_definition(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
         _, body = self.client.create_workflow('wf_v2.yaml')
@@ -241,7 +306,8 @@ class WorkflowTestsV2(base.TestCase):
         self.assertEqual(200, resp.status)
         self.assertIsNotNone(body)
 
-    @test.attr(type='sanity')
+    @decorators.attr(type='sanity')
+    @decorators.idempotent_id('04fbd003-0e52-4034-858e-6634d4f84b29')
     def test_get_workflow_uploaded_in_wb(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
         _, body = self.client.create_workbook('wb_v2.yaml')
@@ -253,18 +319,30 @@ class WorkflowTestsV2(base.TestCase):
 
         self.assertNotEmpty(wf_names)
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('5e5f0403-fb2c-41ae-bf6f-25c181515358')
     def test_get_nonexistent_workflow_definition(self):
         self.assertRaises(exceptions.NotFound,
                           self.client.get_definition,
                           'workflows', 'nonexist')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('23c72d01-c3bb-43d6-ba15-9b49c15f800c')
     def test_get_nonexistent_workflow(self):
         self.assertRaises(exceptions.NotFound, self.client.get_object,
                           'workflows', 'nonexist')
 
-    @test.attr(type='negative')
+        exception = self.assertRaises(
+            exceptions.NotFound,
+            self.client.get_workflow,
+            'nonexist_wf',
+            'nonexist_namespace'
+        )
+        self.assertIn('nonexist_wf', str(exception))
+        self.assertIn('nonexist_namespace', str(exception))
+
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('6b917213-7f11-423a-8fe0-55795dcf0fb2')
     def test_double_create_workflows(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
         _, body = self.client.create_workflow('wf_v2.yaml')
@@ -272,19 +350,22 @@ class WorkflowTestsV2(base.TestCase):
                           self.client.create_workflow,
                           'wf_v2.yaml')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('ffcd63d2-1104-4320-a67b-fadc4e2a0631')
     def test_create_wf_with_invalid_def(self):
         self.assertRaises(exceptions.BadRequest,
                           self.client.create_workflow,
                           'wb_v1.yaml')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('eed46931-5485-436c-810f-1f63362223b9')
     def test_update_wf_with_invalid_def(self):
         self.assertRaises(exceptions.BadRequest,
                           self.client.update_request,
                           'workflows', 'wb_v1.yaml')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('9b7f5b5a-cacd-4f98-a35a-decf065b8234')
     def test_delete_wf_with_trigger_associate(self):
         tr_name = 'trigger'
         resp, body = self.client.create_workflow('wf_v2.yaml')
@@ -303,7 +384,8 @@ class WorkflowTestsV2(base.TestCase):
             self.client.delete_obj('cron_triggers', tr_name)
             self.client.triggers.remove(tr_name)
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('46325022-cbd2-48f3-95f3-e587aab3b655')
     def test_delete_wf_with_event_trigger_associate(self):
         _, body = self.client.create_workflow('wf_v2.yaml')
         wf_id = body['workflows'][0]['id']
@@ -322,7 +404,8 @@ class WorkflowTestsV2(base.TestCase):
             self.client.delete_obj('event_triggers', body['id'])
             self.client.event_triggers.remove(body['id'])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('1cb929e6-d375-4dcb-ab7c-73aa205af896')
     def test_delete_wf_with_trigger_associate_in_other_tenant(self):
         self.useFixture(lockutils.LockFixture('mistral-workflow'))
         tr_name = 'trigger'
@@ -351,7 +434,8 @@ class WorkflowTestsV2(base.TestCase):
             self.alt_client.delete_obj('cron_triggers', tr_name)
             self.alt_client.triggers.remove(tr_name)
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
+    @decorators.idempotent_id('f575713b-27fd-4ec8-b84f-468a7adf5ed2')
     def test_delete_nonexistent_wf(self):
         self.assertRaises(exceptions.NotFound,
                           self.client.delete_obj,
