@@ -18,20 +18,46 @@ import inspect
 import json
 import os
 
-from cinderclient import utils as cinder_base
+from aodhclient.v2 import base as aodh_base
+from aodhclient.v2 import client as aodhclient
+from barbicanclient import base as barbican_base
+from barbicanclient import client as barbicanclient
+from ceilometerclient.v2 import client as ceilometerclient
+from cinderclient.apiclient import base as cinder_base
 from cinderclient.v2 import client as cinderclient
+from designateclient import client as designateclient
 from glanceclient.v2 import client as glanceclient
-from heatclient.openstack.common.apiclient import base as heat_base
+from glareclient.v1 import client as glareclient
+from gnocchiclient.v1 import base as gnocchi_base
+from gnocchiclient.v1 import client as gnocchiclient
+from heatclient.common import base as heat_base
 from heatclient.v1 import client as heatclient
+from ironicclient.common import base as ironic_base
+from ironicclient.v1 import client as ironicclient
 from keystoneclient import base as keystone_base
 from keystoneclient.v3 import client as keystoneclient
-from novaclient.openstack.common.apiclient import base as nova_base
+from magnumclient.common import base as magnum_base
+from magnumclient.v1 import client as magnumclient
+from mistralclient.api import base as mistral_base
+from mistralclient.api.v2 import client as mistralclient
+from muranoclient.common import base as murano_base
+from muranoclient.v1 import client as muranoclient
+from novaclient import base as nova_base
 from novaclient import client as novaclient
-
+from troveclient import base as trove_base
+from troveclient.v1 import client as troveclient
 
 # TODO(nmakhotkin): Find a rational way to do it for neutron.
 # TODO(nmakhotkin): Implement recursive way of searching for managers
 # TODO(nmakhotkin): (e.g. keystone).
+# TODO(dprince): Need to update ironic_inspector_client before we can
+# plug it in cleanly here.
+# TODO(dprince): Swiftclient doesn't currently support discovery
+# like we do in this class.
+# TODO(therve): Zaqarclient doesn't currently support discovery
+# like we do in this class.
+# TODO(sa709c): Tackerclient doesn't currently support discovery
+# like we do in this class.
 
 """It is simple CLI tool which allows to see and update mapping.json file
 if needed. mapping.json contains all allowing OpenStack actions sorted by
@@ -59,6 +85,14 @@ BASE_HEAT_MANAGER = heat_base.HookableMixin
 BASE_NOVA_MANAGER = nova_base.HookableMixin
 BASE_KEYSTONE_MANAGER = keystone_base.Manager
 BASE_CINDER_MANAGER = cinder_base.HookableMixin
+BASE_MISTRAL_MANAGER = mistral_base.ResourceManager
+BASE_TROVE_MANAGER = trove_base.Manager
+BASE_IRONIC_MANAGER = ironic_base.Manager
+BASE_BARBICAN_MANAGER = barbican_base.BaseEntityManager
+BASE_MAGNUM_MANAGER = magnum_base.Manager
+BASE_MURANO_MANAGER = murano_base.Manager
+BASE_AODH_MANAGER = aodh_base.Manager
+BASE_GNOCCHI_MANAGER = gnocchi_base.Manager
 
 
 def get_parser():
@@ -68,7 +102,7 @@ def get_parser():
     )
     parser.add_argument(
         'service',
-        choices=['nova', 'glance', 'heat', 'cinder', 'keystone'],
+        choices=CLIENTS.keys(),
         help='Service name which methods need to be found.'
     )
     parser.add_argument(
@@ -100,9 +134,25 @@ def get_parser():
 
 
 GLANCE_NAMESPACE_LIST = [
-    'image_members', 'image_tags', 'images', 'schemas', 'tasks'
+    'image_members', 'image_tags', 'images', 'schemas', 'tasks',
+    'metadefs_resource_type', 'metadefs_property', 'metadefs_object',
+    'metadefs_tag', 'metadefs_namespace', 'versions'
 ]
 
+CEILOMETER_NAMESPACE_LIST = [
+    'alarms', 'capabilities', 'event_types', 'events', 'meters',
+    'new_samples', 'query_alarm_history', 'query_alarms', 'query_samples',
+    'resources', 'samples', 'statistics', 'trait_descriptions', 'traits'
+]
+
+DESIGNATE_NAMESPACE_LIST = [
+    'diagnostics', 'domains', 'quotas', 'records', 'reports', 'servers',
+    'sync', 'touch'
+]
+
+
+GLARE_NAMESPACE_LIST = ['artifacts', 'versions']
+
 
 def get_nova_client(**kwargs):
     return novaclient.Client(2)
@@ -120,34 +170,112 @@ def get_heat_client(**kwargs):
     return heatclient.Client('')
 
 
+def get_ceilometer_client(**kwargs):
+    return ceilometerclient.Client('')
+
+
 def get_cinder_client(**kwargs):
     return cinderclient.Client()
 
 
+def get_mistral_client(**kwargs):
+    return mistralclient.Client()
+
+
+def get_trove_client(**kwargs):
+    return troveclient.Client('username', 'password')
+
+
+def get_ironic_client(**kwargs):
+    return ironicclient.Client("http://127.0.0.1:6385/")
+
+
+def get_barbican_client(**kwargs):
+    return barbicanclient.Client(
+        project_id="1",
+        endpoint="http://127.0.0.1:9311"
+    )
+
+
+def get_designate_client(**kwargs):
+    return designateclient.Client('1')
+
+
+def get_magnum_client(**kwargs):
+    return magnumclient.Client()
+
+
+def get_murano_client(**kwargs):
+    return muranoclient.Client('')
+
+
+def get_aodh_client(**kwargs):
+    return aodhclient.Client('')
+
+
+def get_gnocchi_client(**kwargs):
+    return gnocchiclient.Client()
+
+
+def get_glare_client(**kwargs):
+    return glareclient.Client('')
+
+
 CLIENTS = {
     'nova': get_nova_client,
     'heat': get_heat_client,
+    'ceilometer': get_ceilometer_client,
     'cinder': get_cinder_client,
     'keystone': get_keystone_client,
     'glance': get_glance_client,
+    'trove': get_trove_client,
+    'ironic': get_ironic_client,
+    'barbican': get_barbican_client,
+    'mistral': get_mistral_client,
+    'designate': get_designate_client,
+    'magnum': get_magnum_client,
+    'murano': get_murano_client,
+    'aodh': get_aodh_client,
+    'gnocchi': get_gnocchi_client,
+    'glare': get_glare_client,
     # 'neutron': get_nova_client
+    # 'baremetal_introspection': ...
+    # 'swift': ...
+    # 'zaqar': ...
 }
 BASE_MANAGERS = {
     'nova': BASE_NOVA_MANAGER,
     'heat': BASE_HEAT_MANAGER,
+    'ceilometer': None,
     'cinder': BASE_CINDER_MANAGER,
     'keystone': BASE_KEYSTONE_MANAGER,
     'glance': None,
+    'trove': BASE_TROVE_MANAGER,
+    'ironic': BASE_IRONIC_MANAGER,
+    'barbican': BASE_BARBICAN_MANAGER,
+    'mistral': BASE_MISTRAL_MANAGER,
+    'designate': None,
+    'magnum': BASE_MAGNUM_MANAGER,
+    'murano': BASE_MURANO_MANAGER,
+    'aodh': BASE_AODH_MANAGER,
+    'gnocchi': BASE_GNOCCHI_MANAGER,
+    'glare': None,
     # 'neutron': BASE_NOVA_MANAGER
+    # 'baremetal_introspection': ...
+    # 'swift': ...
+    # 'zaqar': ...
 }
 NAMESPACES = {
-    'glance': GLANCE_NAMESPACE_LIST
+    'glance': GLANCE_NAMESPACE_LIST,
+    'ceilometer': CEILOMETER_NAMESPACE_LIST,
+    'designate': DESIGNATE_NAMESPACE_LIST,
+    'glare': GLARE_NAMESPACE_LIST
 }
 ALLOWED_ATTRS = ['service_catalog', 'catalog']
 FORBIDDEN_METHODS = [
     'add_hook', 'alternate_service_type', 'completion_cache', 'run_hooks',
     'write_to_completion_cache', 'model', 'build_key_only_query', 'build_url',
-    'head', 'put'
+    'head', 'put', 'unvalidated_model'
 ]
 
 
